@@ -1,5 +1,44 @@
+is_class_package <- function(x, package, classes) {
+    if (isNamespaceLoaded(package)) {
+        for (cls in classes) {
+            attr(cls, "package") <- package
+            if (is(x, cls)) {
+                return(TRUE)
+            }
+        }
+    }
+
+    FALSE
+}
+
 #' @export
-setMethod("initializeCpp", "ANY", function(x, ...) initialize_unknown_matrix(x))
+setMethod("initializeCpp", "ANY", function(x, ...) {
+    if (is_class_package(x, "HDF5Array", c("HDF5ArraySeed", "H5SparseMatrixSeed"))) {
+        # Automatically use beachmat.hdf5 if it's available.  We check that
+        # beachmat.hdf5 is not already loaded to avoid infinite loops in case
+        # beachmat.hdf5 does NOT support the listed classes (so requiring the
+        # namespace would not add any more methods for meaningful dispatch).
+        if (!isNamespaceLoaded("beachmat.hdf5") && requireNamespace("beachmat.hdf5", quietly=TRUE)) {
+            return(initializeCpp(x, ...))
+        }
+    }
+
+    if (is_class_package(x, "alabaster.matrix", "WrapperArraySeed")) {
+        # Pass-through some known no-op matrices from alabaster.matrix.
+        return(initializeCpp(x@seed, ...))
+    }
+
+    # We also provide a lightweight hook to support skipping of classes in
+    # other packages (mostly legacy GNE-internal gunk) that don't want to
+    # import beachmat just to define a no-op initializeCpp() method.
+    for (cls in getOption("beachmat.noop.wrappers", character(0))) {
+        if (is(x, cls)) {
+            return(initializeCpp(x@seed, ...))
+        }
+    }
+
+    initialize_unknown_matrix(x)
+})
 
 #' @export
 setMethod("initializeCpp", "externalptr", function(x, ...) x)
@@ -8,10 +47,10 @@ setMethod("initializeCpp", "externalptr", function(x, ...) x)
 setMethod("initializeCpp", "matrix", function(x, ...) initialize_dense_matrix(x, nrow(x), ncol(x)))
 
 #' @export
-setMethod("initializeCpp", "dgeMatrix", function(x, ...) initialize_dense_matrix(x@x, nrow(x), ncol(x)))
+setMethod("initializeCpp", "dgeMatrix", function(x, ...) initialize_dense_matrix_from_vector(x@x, nrow(x), ncol(x)))
 
 #' @export
-setMethod("initializeCpp", "lgeMatrix", function(x, ...) initialize_dense_matrix(x@x, nrow(x), ncol(x)))
+setMethod("initializeCpp", "lgeMatrix", function(x, ...) initialize_dense_matrix_from_vector(x@x, nrow(x), ncol(x)))
 
 ####################################################################################
 ####################################################################################
@@ -198,6 +237,33 @@ setMethod("initializeCpp", "DelayedUnaryIsoOpWithArgs", function(x, ...) {
         return(apply_delayed_boolean_not(seed))
     }
 
+    if (generic == "type<-") {
+        target.type <- envir$value
+        src.type <- type(envir$x)
+
+        ranking <- c("logical", "raw", "integer", "double")
+        target.i <- which(ranking == target.type)
+        src.i <- which(ranking == src.type)
+        if (length(target.i) == 0L || length(src.i) == 0L) {
+            return(NULL)
+        }
+
+        if (target.i >= src.i) {
+            return(seed)
+        }
+
+        if (target.type == "integer") {
+            # source type must be a wider type, so we truncate.
+            return(apply_delayed_unary_math(seed, "trunc"))
+        } else if (target.type == "logical") {
+            # TODO: add a better 'not-not' method to coerce values to binary.
+            return(apply_delayed_boolean(seed, val=TRUE, row=TRUE, op="&")) 
+        } else {
+            # Raw not supported yet.
+            return(NULL)
+        }
+    }
+
     if (!(generic %in% supported.Ops)) {
         return(NULL)
     }
