@@ -22,12 +22,12 @@ test_that("initialization works correctly with dense matrices", {
         am_i_ok(dd2, ptr)
     }
 
-    de <- Matrix::Matrix(dd)
+    de <- Matrix::Matrix(dd, sparse=FALSE)
     {
         ptr <- initializeCpp(de)
         am_i_ok(de, ptr)
 
-        de2 <- de > 0
+        de2 <- de > 0 # with logical
         ptr <- initializeCpp(de2)
         am_i_ok(de2, ptr)
     }
@@ -66,7 +66,7 @@ test_that("initialization works correctly with SVT sparse matrices", {
     {
         y2 <- y != 0
         z <- as(y2, "SVT_SparseMatrix")
-        ptr <- initializeCpp(y2)
+        ptr <- initializeCpp(z)
         am_i_ok(y2, ptr)
     }
 
@@ -74,7 +74,17 @@ test_that("initialization works correctly with SVT sparse matrices", {
         y2 <- as.matrix(y)
         storage.mode(y2) <- "integer"
         z <- as(y2, "SVT_SparseMatrix")
-        ptr <- initializeCpp(y2)
+        ptr <- initializeCpp(z)
+        am_i_ok(y2, ptr)
+    }
+
+    {
+        y2 <- y
+        y2[,c(1, 100)] <- 0
+        z <- as(y2, "SVT_SparseMatrix")
+        expect_null(z@SVT[[1]])
+        expect_null(z@SVT[[100]])
+        ptr <- initializeCpp(z)
         am_i_ok(y2, ptr)
     }
 })
@@ -133,7 +143,7 @@ test_that("initialization works correctly with DelayedArray combining", {
     am_i_ok(cbind(y, y2), ptr)
 })
 
-test_that("initialization works correctly with an unknown DelayedArray", {
+test_that("initialization works correctly with the HDF5Arrays", {
     library(HDF5Array)
     mat <- matrix(rnorm(50), ncol=5)
     mat2 <- as(mat, "HDF5Array")
@@ -141,7 +151,20 @@ test_that("initialization works correctly with an unknown DelayedArray", {
     ptr <- initializeCpp(mat2)
     am_i_ok(mat, ptr)
 
-    # works in the sparse case.
+    # Package is automatically loaded to expose the specialized methods. 
+    expect_true(isNamespaceLoaded("beachmat.hdf5"))
+})
+
+test_that("initialization works correctly with an unknown DelayedArray", {
+    # Trying with a solid RLE matrix, which we probably won't
+    # support because it's tedious to perform random access. 
+    mat <- RleArray(Rle(sample(10, 200, replace=TRUE)), c(20, 10))
+    expect_s4_class(mat@seed, "SolidRleArraySeed")
+
+    ptr <- initializeCpp(mat)
+    am_i_ok(mat, ptr)
+
+    # Trying with an unsupported operation.
     mat <- DelayedArray(Matrix::rsparsematrix(100, 50, 0.1))
     mat2 <- round(mat, digits=2)
 
